@@ -19,6 +19,7 @@ import os
 import zipfile
 import platform
 
+from termcolor import colored, cprint
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.management.base import BaseCommand, CommandError
@@ -71,7 +72,13 @@ class Command(BaseCommand):
                 if deploy:
                     func = getattr(deploy, name, None)
                     if func:
-                        print("execute %s.Deploy.%s" % (app, name))
+                        cprint(
+                            "execute %s.Deploy.%s" % (app, name),
+                            "blue",
+                            "on_white",
+                            attrs=["bold", "underline"],
+                        )
+                   
                         result = func()
             except Exception as e:
                 continue
\ No newline at end of file
