@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 11185 2018-08-04 18:13:19Z Lavender $
+# $Id: Patch.py 11367 2019-02-19 12:09:40Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-08-05 03:13:19 +0900 (週日, 05 八月 2018) $
-# $Revision: 11185 $
+# $Date: 2019-02-19 21:09:40 +0900 (週二, 19 二月 2019) $
+# $Revision: 11367 $
 #
 # Contributors:
 #  Bear
 #  Yachu
 
+from Iuppiter.DjangoUtil import extendInstalledApps, extendMiddlewareClasses
+
 from .Util import update, populateEnvToSettings
 
 def attachDebugSettings(settingsDict):
@@ -28,24 +30,46 @@ def attachDebugSettings(settingsDict):
 
     @param settingsLocals locals() in settings.py.
     """
-
-    # debug tool bar & django extensions
+    
+    # django extensions
+    import warnings
+    
     try:
-        import debug_toolbar
         import django_extensions
     except ImportError:
-        pass
+        warnings.warn(
+            colored(
+                "Can't import django_extensions."
+                " Please install django-extensions.", 
+                'yellow', attrs=['bold']
+            )
+        )
     else:
-        settingsDict['INSTALLED_APPS'] += ('django_extensions', )
-
-        if settingsDict.get('DEBUG_TOOL_BAR_ENABLE', None):
-            settingsDict['INSTALLED_APPS'] += ('debug_toolbar', )
-            settingsDict['MIDDLEWARE_CLASSES'] += (
-                "debug_toolbar.middleware.DebugToolbarMiddleware", )
-            defaultInternalIP = {
+        extendInstalledApps(settingsDict, ('django_extensions',))
+        
+    # debug tool bar
+    try:
+        import debug_toolbar
+    except ImportError:
+        warnings.warn(
+            colored(
+                "Can't import debug_toolbar."
+                " Please install django-debug-toolbar==1.9.1.", 
+                'yellow', attrs=['bold']
+            )
+        )
+    else:
+        if settingsDict.get('DEBUG_TOOLBAR_ENABLE', None):
+            extendInstalledApps(settingsDict, ('debug_toolbar',))
+            extendMiddlewareClasses(
+                settingsDict, 
+                ("debug_toolbar.middleware.DebugToolbarMiddleware",)
+            )
+            
+            toolbarSettings = {
                 'INTERNAL_IPS': ['127.0.0.1'],
             }
-            update(settingsDict, defaultInternalIP)
+            update(settingsDict, toolbarSettings)
             
             populateEnvToSettings((
                 'INTERNAL_IPS',
